@@ -219,12 +219,12 @@ bonobo_property_bag_create_poa (BonoboPropertyBag *pb)
 	 * new POA.
 	 */
 	policies = g_new0 (CORBA_PolicyList, 1);
-	policies->_maximum = 2;
-	policies->_length  = 2;
+	policies->_maximum = 3;
+	policies->_length  = 3;
 	policies->_buffer = g_new0 (CORBA_Policy,
 				    policies->_length);
 	policies->_release = CORBA_FALSE;
-	
+
 	/*
 	 * Create a new CORBA Policy object which specifies that we
 	 * will be using a ServantManager, thank you very much.
@@ -242,7 +242,7 @@ bonobo_property_bag_create_poa (BonoboPropertyBag *pb)
 		CORBA_exception_free (&ev);
 		return FALSE;
 	}
-	
+
 	/*
 	 * Now, to add a touch more complexity to the whole
 	 * system, we go further than just creating Property
@@ -276,7 +276,26 @@ bonobo_property_bag_create_poa (BonoboPropertyBag *pb)
 		CORBA_exception_free (&ev);
 		return FALSE;
 	}
+
+	/*
+	 * Set the threading model to SINGLE_THREAD_MODEL, otherwise
+	 * an ORB could use the default ORB_CTRL_MODEL, which is to
+	 * let the ORB make threads for requests as it likes.
+	 */
+	policies->_buffer [2] = (CORBA_Policy)
+		PortableServer_POA_create_thread_policy (
+			bonobo_poa (),
+			PortableServer_SINGLE_THREAD_MODEL,
+			&ev);
 	
+	if (ev._major != CORBA_NO_EXCEPTION){
+		g_warning ("Could not create threading policy for BonoboProperty POA");
+		g_free (policies->_buffer);
+		g_free (policies);
+		CORBA_exception_free (&ev);
+		return FALSE;
+	}   
+
 	/*
 	 * Create the BonoboProperty POA as a child of the root
 	 * Bonobo POA.
@@ -963,7 +982,7 @@ bonobo_property_bag_notify_listeners (BonoboPropertyBag *pb,
 	prop = g_hash_table_lookup (pb->priv->props, name);
 
 	g_return_if_fail (prop != NULL);
-	g_return_if_fail (prop->type != new_value->_type);
+/*	g_return_if_fail (prop->type == new_value->_type);*/
 
 	notify_listeners (pb, prop, new_value, ev);
 }
@@ -984,7 +1003,7 @@ bonobo_property_bag_set_value (BonoboPropertyBag *pb,
 
 	g_return_if_fail (prop != NULL);
 	g_return_if_fail (prop->set_prop != NULL);
-	g_return_if_fail (prop->type != value->_type);
+/*	g_return_if_fail (prop->type == value->_type);*/
 
 	prop->set_prop (pb, value, prop->idx, prop->user_data);
 
