@@ -38,6 +38,7 @@ enum {
 	OVERRIDE,
 	REPLACE_OVERRIDE,
 	REINSTATE,
+	RENAME,
 	REMOVE,
 	LAST_SIGNAL
 };
@@ -280,8 +281,12 @@ free_nodedata_tree (BonoboUIXml *tree, BonoboUINode *node, gboolean do_overrides
 static void
 do_set_id (BonoboUIXml *tree, BonoboUINode *node, gpointer id)
 {
-	BonoboUIXmlData *data =
-		bonobo_ui_xml_get_data (tree, node);
+	BonoboUIXmlData *data;
+
+	if (!node)
+		return;
+
+	data = bonobo_ui_xml_get_data (tree, node);
 
 	data->id = id;
 
@@ -327,14 +332,15 @@ dump_internals (BonoboUIXml *tree, BonoboUINode *node)
 	for (i = 0; i < indent; i++)
 		fprintf (stderr, " ");
 
-	fprintf (stderr, "%s name=\"%s\" ", bonobo_ui_node_get_name (node),
-		 (txt = bonobo_ui_node_get_attr (node, "name")));
+	fprintf (stderr, "%10s name=\"%10s\" ", bonobo_ui_node_get_name (node),
+		 (txt = bonobo_ui_node_get_attr (node, "name")) ? txt : "NULL");
 	if (txt)
 		bonobo_ui_node_free_string (txt);
+
 	fprintf (stderr, "%d len %d", data->dirty,
 		 g_slist_length (data->overridden));
 	if (tree->dump)
-		tree->dump (data);
+		tree->dump (tree, node);
 	else
 		fprintf (stderr, "\n");
 
@@ -406,8 +412,6 @@ prune_overrides_by_id (BonoboUIXml *tree, BonoboUIXmlData *data, gpointer id)
 {
 	GSList *l, *next;
 
-	g_return_if_fail (id != NULL);
-	
 	for (l = data->overridden; l; l = next) {
 		BonoboUIXmlData *o_data;
 				
@@ -438,17 +442,20 @@ override_node_with (BonoboUIXml *tree, BonoboUINode *old, BonoboUINode *new)
 
 	same = identical (tree, data->id, old_data->id);
 
-	if (!data->id)
-		same = TRUE;
+	g_assert (data->id);
+/*	if (!data->id)
+	same = TRUE;*/
+
+	if (!same && !transparent) {
 
-	if (!same) {
 		gtk_signal_emit (GTK_OBJECT (tree), signals [OVERRIDE], old);
 
-		prune_overrides_by_id (tree, data, data->id);
 		data->overridden = g_slist_prepend (old_data->overridden, old);
-		
+		prune_overrides_by_id (tree, data, data->id);
 	} else {
-		data->id = old_data->id;
+		if (transparent)
+			data->id = old_data->id;
+
 		data->overridden = old_data->overridden;
 		gtk_signal_emit (GTK_OBJECT (tree), signals [REPLACE_OVERRIDE], new, old);
 
@@ -459,7 +466,6 @@ override_node_with (BonoboUIXml *tree, BonoboUINode *old, BonoboUINode *new)
 
 	old_data->overridden = NULL;
 
-
  	/* This code doesn't work right with opaque BonoboUINode object */
  	if (bonobo_ui_node_children (new))
  		merge (tree, old, (BonoboUINode**)&XML_NODE (new)->childs);
@@ -525,7 +531,7 @@ reinstate_old_node (BonoboUIXml *tree, BonoboUINode *node)
 		/* Mark dirty */
 		bonobo_ui_xml_set_dirty (tree, node);
 		
-		gtk_signal_emit (GTK_OBJECT (tree), signals [REINSTATE], node);
+		gtk_signal_emit (GTK_OBJECT (tree), signals [RENAME], node);
 		return;
 	}
 /*		fprintf (stderr, "destroying node '%s' '%s'\n",
@@ -905,7 +911,13 @@ bonobo_ui_xml_merge (BonoboUIXml  *tree,
 
 	current = bonobo_ui_xml_get_path (tree, path);
 	if (!current) {
-		/* FIXME: we leak nodes here */
+		xmlNode *l, *next;
+
+		for (l = XML_NODE (nodes); l; l = next) {
+			next = l->next;
+			node_free (tree, BNODE (l));
+		}
+
 		return BONOBO_UI_XML_INVALID_PATH;
 	}
 
@@ -999,6 +1011,13 @@ bonobo_ui_xml_class_init (BonoboUIXmlClass *klass)
 		gtk_marshal_NONE__POINTER,
 		GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
 
+	signals [RENAME] = gtk_signal_new (
+		"rename", GTK_RUN_FIRST,
+		object_class->type,
+		GTK_SIGNAL_OFFSET (BonoboUIXmlClass, rename),
+		gtk_marshal_NONE__POINTER,
+		GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+
 	signals [REMOVE] = gtk_signal_new (
 		"remove", GTK_RUN_FIRST,
 		object_class->type,
