@@ -348,7 +348,7 @@ efs_commit (EFSDir *root)
 }
 
 /**
- * efs_rollback:
+ * efs_revert:
  * @root: reference to the #EFS root directory
  *
  * Description: undo all changes since last commit
@@ -357,7 +357,7 @@ efs_commit (EFSDir *root)
  */
 
 EFSResult
-efs_rollback (EFSDir *root)
+efs_revert (EFSDir *root)
 {
 	g_return_val_if_fail (root != NULL, EFS_ERR_INVAL);
 	g_return_val_if_fail (root->mode&EFS_ROOT, EFS_ERR_INVAL);
@@ -366,7 +366,7 @@ efs_rollback (EFSDir *root)
 	
 	efs_typehash_clear (root->efs);
 
-	return root->efs->driver->sops->rollback (root);
+	return root->efs->driver->sops->revert (root);
 }
 
 /**
