@@ -101,7 +101,7 @@ EFSResult    efs_open_cb       (EFSDir **dir, const char *path, gint flags,
 				gint mode, EFSPassFunc pass_func);
 EFSResult    efs_close         (EFSDir *root);
 EFSResult    efs_commit        (EFSDir *root);
-EFSResult    efs_rollback      (EFSDir *root);
+EFSResult    efs_revert        (EFSDir *root);
 EFSResult    efs_fsstat        (EFSDir *root, EFSFSStat *fsstat);
 
 gchar       *efs_strerror      (EFSResult errnum);
