@@ -40,7 +40,7 @@ static EFSResult  ib1_create   (EFSDir **dir, EFSDriver *driver,
 				gchar *passwd);
 static EFSResult  ib1_close    (EFSDir *root);
 static EFSResult  ib1_commit   (EFSDir *root);
-static EFSResult  ib1_rollback (EFSDir *root);
+static EFSResult  ib1_revert   (EFSDir *root);
 static EFSResult  ib1_fsstat   (EFSDir *root, EFSFSStat *fsstat);
 
 EFSSuperOps super_ops_ib1 = {
@@ -48,7 +48,7 @@ EFSSuperOps super_ops_ib1 = {
 	ib1_create,
 	ib1_close,
 	ib1_commit,
-	ib1_rollback,
+	ib1_revert,
 	ib1_fsstat,
 };
 
@@ -372,7 +372,7 @@ ib1_commit (EFSDir *root)
 }
 
 static EFSResult 
-ib1_rollback (EFSDir *root)
+ib1_revert (EFSDir *root)
 {
 	IB1EFS *efs = (IB1EFS *)root->efs;
 	IB1CacheEntry *ce;
