@@ -2,7 +2,7 @@
  * bonobo-storage-efs.c: libefs based Storage implementation
  *
  * Author:
- *   Dietmar Maurer (dm@vlsivie.tuwien.ac.at)
+ *   Dietmar Maurer (dietmar@maurer-it.com)
  *
  *
  * Problems:
@@ -44,8 +44,7 @@ bonobo_storage_efs_destroy (GtkObject *object)
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (object);
 	
 	if (storage_efs->owner) {
-		if (storage_efs->dir)
-			efs_dir_close (storage_efs->dir);
+		if (storage_efs->dir) efs_dir_close (storage_efs->dir);
 		bonobo_object_unref (BONOBO_OBJECT (storage_efs->owner));    
 	} else {
 		if (storage_efs->dir)
@@ -53,13 +52,25 @@ bonobo_storage_efs_destroy (GtkObject *object)
 	}
 }
 
-static BonoboStream *
-real_create_stream (BonoboStorage *storage, const CORBA_char *path, 
-		    CORBA_Environment *ev)
+static Bonobo_StorageInfo*
+real_get_info (BonoboStorage *storage,
+	       const CORBA_char *path,
+	       const Bonobo_StorageInfoFields mask,
+	       CORBA_Environment *ev)
 {
-	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
+	g_warning ("Not implemented");
 
-	return bonobo_stream_efs_create (storage_efs, path);
+	return CORBA_OBJECT_NIL;
+}
+
+static void
+real_set_info (BonoboStorage *storage,
+	       const CORBA_char *path,
+	       const Bonobo_StorageInfo *info,
+	       const Bonobo_StorageInfoFields mask,
+	       CORBA_Environment *ev)
+{
+	g_warning ("Not implemented");
 }
 
 static BonoboStream *
@@ -67,43 +78,23 @@ real_open_stream (BonoboStorage *storage, const CORBA_char *path,
 		  Bonobo_Storage_OpenMode mode, CORBA_Environment *ev)
 {
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
-	
+
 	return bonobo_stream_efs_open (storage_efs, path, mode);
 }
 
 
-static BonoboStorage *
-real_create_storage (BonoboStorage *storage, const CORBA_char *path, 
-		     CORBA_Environment *ev)
-{
-	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
-	BonoboStorageEFS *sefs;
-	EFSDir *dir;
-
-	if (efs_dir_open (&dir, storage_efs->dir, path, EFS_CREATE|EFS_EXCL)) {
-		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
-				     ex_Bonobo_Storage_NameExists, NULL);
-		return NULL;
-	}
-	
-	sefs = gtk_type_new (bonobo_storage_efs_get_type ());
-	sefs->dir = dir;
-	sefs->owner = storage;
-	bonobo_object_ref (BONOBO_OBJECT (storage));
-	create_storage_efs_server (sefs);
-
-	return BONOBO_STORAGE (sefs);
-}
-
 static BonoboStorage *
 real_open_storage (BonoboStorage *storage, const CORBA_char *path, 
-		   CORBA_Environment *ev)
+		   Bonobo_Storage_OpenMode mode, CORBA_Environment *ev)
 {
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
 	BonoboStorageEFS *sefs;
 	EFSDir *dir;
+	gint efs_mode;
 
-	if (efs_dir_open (&dir, storage_efs->dir, path, 0)) {
+	efs_mode = bonobo_mode_to_efs (mode);
+
+	if (efs_dir_open (&dir, storage_efs->dir, path, efs_mode)) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Storage_NotFound, NULL);
 		return NULL;
@@ -148,17 +139,28 @@ real_commit (BonoboStorage *storage, CORBA_Environment *ev)
 	efs_commit (storage_efs->dir);
 }
 
-
-static Bonobo_Storage_directory_list *
-real_list_contents (BonoboStorage *storage, const CORBA_char *path, 
-		    CORBA_Environment *ev)
+static void
+real_revert (BonoboStorage *storage, CORBA_Environment *ev)
 {
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
-	Bonobo_Storage_directory_list *list;
+
+	if (storage_efs->owner)
+		return;
+
+	efs_revert (storage_efs->dir);
+}
+
+
+static Bonobo_Storage_DirectoryList *
+real_list_contents (BonoboStorage *storage, const CORBA_char *path, 
+		    Bonobo_StorageInfoFields mask, CORBA_Environment *ev)
+{
+	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
+	Bonobo_Storage_DirectoryList *list;
 	EFSDir *dir;
 	int i;
 
-	list = Bonobo_Storage_directory_list__alloc();
+	list = Bonobo_Storage_DirectoryList__alloc();
 	CORBA_sequence_set_release (list, TRUE); 
 
 	if (!efs_dir_open (&dir, storage_efs->dir, path, 0)) {
@@ -172,10 +174,19 @@ real_list_contents (BonoboStorage *storage, const CORBA_char *path,
 		
 	if (!efs_dir_open (&dir, storage_efs->dir, path, 0)) {
 		EFSDirEntry de;
-		char **buf = CORBA_sequence_CORBA_string_allocbuf (i);
+		Bonobo_StorageInfo *buf;
+		
+		buf = CORBA_sequence_Bonobo_StorageInfo_allocbuf (i);
 	
-		for (i = 0; !(efs_dir_read (dir, &de)); i++)
-			buf [i] = CORBA_string_dup (de.name);
+		for (i = 0; !(efs_dir_read (dir, &de)); i++) {
+			buf[i].name = CORBA_string_dup (de.name);
+			if (de.type == EFS_DIR)
+				buf[i].type = Bonobo_STORAGE_TYPE_DIRECTORY;
+			else buf[i].type = Bonobo_STORAGE_TYPE_REGULAR;
+
+			buf[i].content_type = CORBA_string_dup("");
+			buf[i].size = 0;
+		}
 
 		list->_length = i;
 		list->_buffer = buf;
@@ -210,17 +221,17 @@ bonobo_storage_efs_class_init (BonoboStorageEFSClass *class)
 	GtkObjectClass     *oclass = (GtkObjectClass *) class;
 	BonoboStorageClass *sclass = (BonoboStorageClass *) class;
 
-	sclass->create_stream  = real_create_stream;
+	sclass->get_info       = real_get_info;
+	sclass->set_info       = real_set_info;
 	sclass->open_stream    = real_open_stream;
-
-	sclass->create_storage = real_create_storage;
 	sclass->open_storage   = real_open_storage;
 	sclass->copy_to        = real_copy_to;
 	sclass->rename         = real_rename;
 	sclass->commit         = real_commit;
+	sclass->revert         = real_revert;
 	sclass->list_contents  = real_list_contents;
 	sclass->erase          = real_erase;
-
+	
 	oclass->destroy = bonobo_storage_efs_destroy;
 }
 
@@ -264,14 +275,7 @@ bonobo_storage_efs_open (const gchar *path, gint flags, gint mode)
 	BonoboStorageEFS *sefs;
 	gint efs_flags = 0;
 
-	if (flags & Bonobo_Storage_READ)
-		efs_flags |= EFS_READ;
-	if (flags & Bonobo_Storage_WRITE)
-		efs_flags |= EFS_WRITE;
-	if (flags & Bonobo_Storage_CREATE)
-		efs_flags |= EFS_CREATE;
-	if (flags & Bonobo_Storage_FAILIFEXIST)
-		efs_flags |= EFS_EXCL;
+	efs_flags = bonobo_mode_to_efs (flags);
 
 	sefs = gtk_type_new (bonobo_storage_efs_get_type ());
 
