@@ -31,7 +31,7 @@
 #include <bonobo/bonobo.h>
 #include <bonobo/bonobo-object-directory.h>
 
-#include <bonobo/bonobo-stream-fs.h>
+#include <storage-modules/bonobo-stream-fs.h>
 
 CORBA_Environment ev;
 CORBA_ORB orb;
@@ -115,7 +115,8 @@ hydrate_object_from_file_cb (GtkWidget *ok_btn, Bonobo_PersistStream persist)
 	gchar *filename = gtk_file_selection_get_filename (fs);
 	
 	BonoboStream *stream
-		= bonobo_stream_fs_open (filename, Bonobo_Storage_READ);
+		= bonobo_stream_open ("fs", filename, 
+				      Bonobo_Storage_READ, 0644);
 
 	Bonobo_Stream stream_obj =
 		(Bonobo_Stream) bonobo_object_corba_objref (BONOBO_OBJECT (stream));
